@@ -63,13 +63,9 @@ public:
 
     [[nodiscard]] MediaPlayListProxyModel* playList() const;
 
-    void setSourceModel(QAbstractItemModel *sourceModel) override;
-
 public Q_SLOTS:
 
-    void enqueueToPlayList(const QModelIndex &rootIndex);
-
-    void replaceAndPlayOfPlayList(const QModelIndex &rootIndex);
+    void enqueueAll(ElisaUtils::PlayListEnqueueMode enqueueMode, ElisaUtils::PlayListEnqueueTriggerPlay triggerPlay);
 
     void enqueue(const DataTypes::MusicDataType &newEntry,
                  const QString &newEntryTitle,
@@ -98,8 +94,6 @@ Q_SIGNALS:
 
     void playListChanged();
 
-protected:
-
 private Q_SLOTS:
 
     void listRecursiveResult(KJob *job);
@@ -124,7 +118,7 @@ private:
 
     MediaPlayListProxyModel* mPlayList = nullptr;
 
-    bool mFilterRating = false;
+    int mFilterRating = 0;
 
     QMimeDatabase mMimeDatabase;
 
